@@ -54,35 +54,7 @@ _GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("dialogflow").version
 
 
 class EntityTypesClient(object):
-    """
-    Entities are extracted from user input and represent parameters that are
-    meaningful to your application. For example, a date range, a proper name
-    such as a geographic location or landmark, and so on. Entities represent
-    actionable data for your application.
-
-    When you define an entity, you can also include synonyms that all map to
-    that entity. For example, "soft drink", "soda", "pop", and so on.
-
-    There are three types of entities:
-
-    -  **System** - entities that are defined by the Dialogflow API for
-       common data types such as date, time, currency, and so on. A system
-       entity is represented by the ``EntityType`` type.
-
-    -  **Custom** - entities that are defined by you that represent
-       actionable data that is meaningful to your application. For example,
-       you could define a ``pizza.sauce`` entity for red or white pizza
-       sauce, a ``pizza.cheese`` entity for the different types of cheese on
-       a pizza, a ``pizza.topping`` entity for different toppings, and so
-       on. A custom entity is represented by the ``EntityType`` type.
-
-    -  **User** - entities that are built for an individual user such as
-       favorites, preferences, playlists, and so on. A user entity is
-       represented by the ``SessionEntityType`` type.
-
-    For more information about entity types, see the `Dialogflow
-    documentation <https://cloud.google.com/dialogflow/docs/entities-overview>`__.
-    """
+    """Service for managing ``EntityTypes``."""
 
     SERVICE_ADDRESS = "dialogflow.googleapis.com:443"
     """The default address of the service."""
@@ -111,6 +83,20 @@ class EntityTypesClient(object):
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def project_agent_path(cls, project):
+        """Return a fully-qualified project_agent string."""
+        return google.api_core.path_template.expand(
+            "projects/{project}/agent", project=project
+        )
+
+    @classmethod
+    def agent_path(cls, project):
+        """Return a fully-qualified agent string."""
+        return google.api_core.path_template.expand(
+            "projects/{project}/agent", project=project
+        )
+
     @classmethod
     def entity_type_path(cls, project, entity_type):
         """Return a fully-qualified entity_type string."""
@@ -120,13 +106,6 @@ class EntityTypesClient(object):
             entity_type=entity_type,
         )
 
-    @classmethod
-    def project_agent_path(cls, project):
-        """Return a fully-qualified project_agent string."""
-        return google.api_core.path_template.expand(
-            "projects/{project}/agent", project=project
-        )
-
     def __init__(
         self,
         transport=None,
@@ -257,7 +236,7 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2.EntityTypesClient()
             >>>
-            >>> parent = client.project_agent_path('[PROJECT]')
+            >>> parent = client.agent_path('[PROJECT]')
             >>>
             >>> # Iterate over all results
             >>> for element in client.list_entity_types(parent):
@@ -276,11 +255,10 @@ class EntityTypesClient(object):
         Args:
             parent (str): Required. The agent to list all entity types from. Format:
                 ``projects/<Project ID>/agent``.
-            language_code (str): Optional. The language to list entity synonyms for. If not specified,
-                the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             page_size (int): The maximum number of resources contained in the
                 underlying API response. If page streaming is performed per-
                 resource, this parameter does not affect the return value. If page
@@ -373,11 +351,10 @@ class EntityTypesClient(object):
         Args:
             name (str): Required. The name of the entity type. Format:
                 ``projects/<Project ID>/agent/entityTypes/<EntityType ID>``.
-            language_code (str): Optional. The language to retrieve entity synonyms for. If not
-                specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
                 to retry requests. If ``None`` is specified, requests will
                 be retried using a default configuration.
@@ -445,7 +422,7 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2.EntityTypesClient()
             >>>
-            >>> parent = client.project_agent_path('[PROJECT]')
+            >>> parent = client.agent_path('[PROJECT]')
             >>>
             >>> # TODO: Initialize `entity_type`:
             >>> entity_type = {}
@@ -459,11 +436,10 @@ class EntityTypesClient(object):
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2.types.EntityType`
-            language_code (str): Optional. The language of entity synonyms defined in ``entity_type``. If
-                not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
                 to retry requests. If ``None`` is specified, requests will
                 be retried using a default configuration.
@@ -541,11 +517,10 @@ class EntityTypesClient(object):
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2.types.EntityType`
-            language_code (str): Optional. The language of entity synonyms defined in ``entity_type``. If
-                not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             update_mask (Union[dict, ~google.cloud.dialogflow_v2.types.FieldMask]): Optional. The mask to control which fields get updated.
 
                 If a dict is provided, it must be of the same form as the protobuf
@@ -690,7 +665,7 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2.EntityTypesClient()
             >>>
-            >>> parent = client.project_agent_path('[PROJECT]')
+            >>> parent = client.agent_path('[PROJECT]')
             >>>
             >>> response = client.batch_update_entity_types(parent)
             >>>
@@ -714,11 +689,10 @@ class EntityTypesClient(object):
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2.types.EntityTypeBatch`
-            language_code (str): Optional. The language of entity synonyms defined in ``entity_types``.
-                If not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             update_mask (Union[dict, ~google.cloud.dialogflow_v2.types.FieldMask]): Optional. The mask to control which fields get updated.
 
                 If a dict is provided, it must be of the same form as the protobuf
@@ -808,7 +782,7 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2.EntityTypesClient()
             >>>
-            >>> parent = client.project_agent_path('[PROJECT]')
+            >>> parent = client.agent_path('[PROJECT]')
             >>>
             >>> # TODO: Initialize `entity_type_names`:
             >>> entity_type_names = []
@@ -827,8 +801,8 @@ class EntityTypesClient(object):
         Args:
             parent (str): Required. The name of the agent to delete all entities types for.
                 Format: ``projects/<Project ID>/agent``.
-            entity_type_names (list[str]): Required. The names entity types to delete. All names must point to the
-                same agent as ``parent``.
+            entity_type_names (list[str]): Required. The names entity types to delete. All names must point to
+                the same agent as ``parent``.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
                 to retry requests. If ``None`` is specified, requests will
                 be retried using a default configuration.
@@ -927,11 +901,10 @@ class EntityTypesClient(object):
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2.types.Entity`
-            language_code (str): Optional. The language of entity synonyms defined in ``entities``. If
-                not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
                 to retry requests. If ``None`` is specified, requests will
                 be retried using a default configuration.
@@ -999,8 +972,8 @@ class EntityTypesClient(object):
         metadata=None,
     ):
         """
-        Updates or creates multiple entities in the specified entity type. This
-        method does not affect entities in the entity type that aren't
+        Updates or creates multiple entities in the specified entity type.
+        This method does not affect entities in the entity type that aren't
         explicitly specified in the request.
 
         Operation <response: ``google.protobuf.Empty``>
@@ -1027,17 +1000,17 @@ class EntityTypesClient(object):
             >>> metadata = response.metadata()
 
         Args:
-            parent (str): Required. The name of the entity type to update or create entities in.
-                Format: ``projects/<Project ID>/agent/entityTypes/<Entity Type ID>``.
+            parent (str): Required. The name of the entity type to update or create entities
+                in. Format:
+                ``projects/<Project ID>/agent/entityTypes/<Entity Type ID>``.
             entities (list[Union[dict, ~google.cloud.dialogflow_v2.types.Entity]]): Required. The entities to update or create.
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2.types.Entity`
-            language_code (str): Optional. The language of entity synonyms defined in ``entities``. If
-                not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             update_mask (Union[dict, ~google.cloud.dialogflow_v2.types.FieldMask]): Optional. The mask to control which fields get updated.
 
                 If a dict is provided, it must be of the same form as the protobuf
@@ -1139,14 +1112,13 @@ class EntityTypesClient(object):
         Args:
             parent (str): Required. The name of the entity type to delete entries for. Format:
                 ``projects/<Project ID>/agent/entityTypes/<Entity Type ID>``.
-            entity_values (list[str]): Required. The reference ``values`` of the entities to delete. Note that
-                these are not fully-qualified names, i.e. they don't start with
+            entity_values (list[str]): Required. The reference ``values`` of the entities to delete. Note
+                that these are not fully-qualified names, i.e. they don't start with
                 ``projects/<Project ID>``.
-            language_code (str): Optional. The language of entity synonyms defined in ``entities``. If
-                not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
                 to retry requests. If ``None`` is specified, requests will
                 be retried using a default configuration.
