@@ -42,6 +42,8 @@ from dialogflow_v2beta1.proto import document_pb2
 from dialogflow_v2beta1.proto import document_pb2_grpc
 from dialogflow_v2beta1.proto import entity_type_pb2
 from dialogflow_v2beta1.proto import entity_type_pb2_grpc
+from dialogflow_v2beta1.proto import environment_pb2
+from dialogflow_v2beta1.proto import environment_pb2_grpc
 from dialogflow_v2beta1.proto import gcs_pb2
 from dialogflow_v2beta1.proto import intent_pb2
 from dialogflow_v2beta1.proto import intent_pb2_grpc
@@ -60,24 +62,7 @@ _GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("dialogflow").version
 
 
 class SessionEntityTypesClient(object):
-    """
-    Entities are extracted from user input and represent parameters that are
-    meaningful to your application. For example, a date range, a proper name
-    such as a geographic location or landmark, and so on. Entities represent
-    actionable data for your application.
-
-    Session entity types are referred to as **User** entity types and are
-    entities that are built for an individual user such as favorites,
-    preferences, playlists, and so on. You can redefine a session entity
-    type at the session level.
-
-    Session entity methods do not work with Google Assistant integration.
-    Contact Dialogflow support if you need to use session entities with
-    Google Assistant integration.
-
-    For more information about entity types, see the `Dialogflow
-    documentation <https://cloud.google.com/dialogflow/docs/entities-overview>`__.
-    """
+    """Service for managing ``SessionEntityTypes``."""
 
     SERVICE_ADDRESS = "dialogflow.googleapis.com:443"
     """The default address of the service."""
@@ -283,7 +268,8 @@ class SessionEntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.SessionEntityTypesClient()
             >>>
-            >>> parent = client.session_path('[PROJECT]', '[SESSION]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> # Iterate over all results
             >>> for element in client.list_session_entity_types(parent):
@@ -394,7 +380,8 @@ class SessionEntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.SessionEntityTypesClient()
             >>>
-            >>> name = client.session_entity_type_path('[PROJECT]', '[SESSION]', '[ENTITY_TYPE]')
+            >>> # TODO: Initialize `name`:
+            >>> name = ''
             >>>
             >>> response = client.get_session_entity_type(name)
 
@@ -477,7 +464,8 @@ class SessionEntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.SessionEntityTypesClient()
             >>>
-            >>> parent = client.session_path('[PROJECT]', '[SESSION]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> # TODO: Initialize `session_entity_type`:
             >>> session_entity_type = {}
@@ -571,13 +559,7 @@ class SessionEntityTypesClient(object):
             >>> response = client.update_session_entity_type(session_entity_type)
 
         Args:
-            session_entity_type (Union[dict, ~google.cloud.dialogflow_v2beta1.types.SessionEntityType]): Required. The entity type to update. Format:
-                ``projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type Display Name>``
-                or
-                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session ID>/entityTypes/<Entity Type Display Name>``.
-                If ``Environment ID`` is not specified, we assume default 'draft'
-                environment. If ``User ID`` is not specified, we assume default '-'
-                user.
+            session_entity_type (Union[dict, ~google.cloud.dialogflow_v2beta1.types.SessionEntityType]): Required. The session entity type to update.
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.SessionEntityType`
@@ -654,7 +636,8 @@ class SessionEntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.SessionEntityTypesClient()
             >>>
-            >>> name = client.session_entity_type_path('[PROJECT]', '[SESSION]', '[ENTITY_TYPE]')
+            >>> # TODO: Initialize `name`:
+            >>> name = ''
             >>>
             >>> client.delete_session_entity_type(name)
 
